#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hashable-time
version:              0.3
visibility:           public
id:                   hashable-time-0.3-2kZCBB5oRWZFRKaN62voQy
key:                  hashable-time-0.3-2kZCBB5oRWZFRKaN62voQy
license:              BSD-3-Clause
maintainer:           Alexey Karakulov <ankarakulov@gmail.com>
author:               Alexey Karakulov <ankarakulov@gmail.com>
synopsis:             Hashable instances for Data.Time
description:          Hashable instances for types in Data.Time
category:             Data
abi:                  4e9a80061e50fd4b38808393d6f3a730
exposed:              True
exposed-modules:      Data.Hashable.Time
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hashable-time
hs-libraries:         HShashable-time-0.3-2kZCBB5oRWZFRKaN62voQy
depends:
    base-4.18.2.1 time-compat-1.9.9-2MIxBPFfFBFIllY9erJrbb

haddock-interfaces:
    /usr/share/doc/haskell-hashable-time/html/hashable-time.haddock

haddock-html:         /usr/share/doc/haskell-hashable-time/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

